@@ -1,12 +1,12 @@
 package WWW::Google::Contacts::Type::PostalAddress;
 
 BEGIN {
-    $WWW::Google::Contacts::Type::PostalAddress::VERSION = '0.29';
+    $WWW::Google::Contacts::Type::PostalAddress::VERSION = '0.30';
 }
 
 use Moose;
 use MooseX::Types::Moose qw( Str );
-use WWW::Google::Contacts::InternalTypes qw( Rel XmlBool );
+use WWW::Google::Contacts::InternalTypes qw( Rel XmlBool Country );
 use WWW::Google::Contacts::Meta::Attribute::Trait::XmlField;
 
 extends 'WWW::Google::Contacts::Type::Base';
@@ -128,11 +128,12 @@ has postcode => (
 );
 
 has country => (
-    isa        => Str,
+    isa        => Country,
     is         => 'rw',
     traits     => ['XmlField'],
     xml_key    => 'gd:country',
     predicate  => 'has_country',
+    coerce     => 1,
     is_element => 1,
 );
 
